@@ -28,10 +28,10 @@ def push_software(config, fpath, radarType, version_name):
 
     # check if can open file path
     if os.path.isfile(fpath):
-        logging.info("ZIP file exists: " + fpath)
+        logger.log(message="ZIP file exists: " + fpath, log_level="info", to_file=True, to_terminal=True)
         # print("ZIP file exists: " + fpath)
     else:
-        logging.error("ZIP not exist: " + fpath)
+        logger.log(message="ZIP not exist: " + fpath, log_level="error", to_file=True, to_terminal=True)
         # print("ZIP not exist: " + fpath)
         return "ZIP not exist: " + fpath
         
@@ -48,7 +48,7 @@ def push_software(config, fpath, radarType, version_name):
     # print('versionName: ', version_name)
     # print('values.versionName: ', values['versionName'])
 
-    logging.log(message="Pushing software to Robin SD", log_level="info", to_file=True, to_terminal=True)
+    logger.log(message="Pushing software to Robin SD", log_level="info", to_file=True, to_terminal=True)
 
     response = requests.post(request_url + '/api/softwares/softwarefiles', headers=headers, data=values, files=files)
     return response.json()
\ No newline at end of file
