@@ -10,12 +10,10 @@ from robin_sd_upload import _version
 from robin_sd_upload.slack_interaction import slack_handler
 from robin_sd_upload.supportive_scripts import yaml_parser
 from robin_sd_upload.supportive_scripts import logger
-from robin_sd_upload.supportive_scripts import validate
-from robin_sd_upload.supportive_scripts import create_zip
-from robin_sd_upload.supportive_scripts import remove_zip
-# from robin_sd_upload.supportive_scripts import check_upload_file
-from arg_parse import check_upload_file
-
+from supportive_scripts import validate
+from supportive_scripts import create_zip
+from supportive_scripts import remove_zip
+from  supportive_scripts import check_upload_file
 
 def arg_parser():
     parser = argparse.ArgumentParser(
@@ -56,7 +54,7 @@ def arg_parser():
             print('Please provide all the arguments: --type, --version, --source')
             exit(1)
         # check if the radar type is valid
-        # validate(radarType, version_name)
+        validate(radarType, version_name)
         if check_upload_file(upload_file_path, version_name) is False:
             exit(1)
         temp_dir = tempfile.mkdtemp()
